@@ -103,8 +103,6 @@ class SQLiteFileCache(BaseCache):
 
                 self._conn.execute('''INSERT INTO cache_entries (key, value, expires_at) VALUES (?, ?, ?)''', (key, pickled_value, expiry))
 
-
-
     def touch(self, key, timeout=DEFAULT_TIMEOUT, version=None):
         key = self.make_key(key, version=version)
         self.validate_key(key)
@@ -120,9 +118,9 @@ class SQLiteFileCache(BaseCache):
             else:
                 expiry = self.get_backend_timeout(timeout)
                 with self._conn:
-                    self._conn.execute(
+                    cur = self._conn.execute(
                         '''UPDATE cache_entries SET expires_at = ? WHERE key = ?''', (expiry, key,))
-                return True
+                    return cur.rowcount > 0
         else:
             return False
 
